<?php
/*
Plugin Name: WhatsApp Order Notifier via Twilio
Description: שליחת הודעת WhatsApp עם פרטי ההזמנה ללקוחות באמצעות Twilio כאשר הזמנה ב-WooCommerce מושלמת.
Version: 1.0
Author: pablo rotem
*/

if (!defined('ABSPATH')) {
    exit; // מניעת גישה ישירה לקובץ
}

add_action('woocommerce_order_status_completed', 'send_whatsapp_message_with_twilio', 10, 1);

function send_whatsapp_message_with_twilio($order_id) {
    // קבלת פרטי ההזמנה
    $order = wc_get_order($order_id);
    $client_phone = $order->get_billing_phone(); // בהנחה שמספר הטלפון של הלקוח שמור בפרטי החיוב
    $order_details = '';

    // בניית ההודעה עם פרטי המוצרים
    foreach ($order->get_items() as $item) {
        $product_name = $item->get_name();
        $quantity = $item->get_quantity();
        $total = $item->get_total();
        $order_details .= "$product_name (x$quantity) - $total\n";
    }

    $message = "תודה על ההזמנה שלך! הנה פרטי ההזמנה:\n\n$order_details\nסה\"כ לתשלום: " . $order->get_total();

    // שליחת הודעת WhatsApp באמצעות Twilio API
    send_whatsapp_via_twilio($client_phone, $message);
}

function send_whatsapp_via_twilio($phone, $message) {
    $account_sid = 'your_account_sid';  // ה-Account SID שלך מ-Twilio
    $auth_token = 'your_auth_token';    // אסימון האימות שלך מ-Twilio
    $twilio_number = 'whatsapp:+your_twilio_whatsapp_number';  // מספר ה-WhatsApp שלך ב-Twilio

    $client = new \Twilio\Rest\Client($account_sid, $auth_token);

    try {
        $client->messages->create(
            'whatsapp:+' . sanitize_phone_number($phone), // מספר WhatsApp של הלקוח
            [
                'from' => $twilio_number, // מספר ה-WhatsApp של Twilio
                'body' => $message
            ]
        );
        error_log("הודעת WhatsApp נשלחה בהצלחה ל-$phone");
    } catch (Exception $e) {
        error_log("שליחת הודעת WhatsApp נכשלה: " . $e->getMessage());
    }
}

function sanitize_phone_number($phone) {
    return preg_replace('/[^0-9]/', '', $phone); // ניקוי המספר כך שיכיל רק ספרות
}
